==> xmlunit-legacy-2.8.3-sources.jar: org/custommonkey/xmlunit/NodeDetail.java <==
/*
******************************************************************
Copyright (c) 2001,2015 Jeff Martin, Tim Bacon
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
      copyright notice, this list of conditions and the following
      disclaimer in the documentation and/or other materials provided
      with the distribution.
    * Neither the name of the XMLUnit nor the names
      of its contributors may be used to endorse or promote products
      derived from this software without specific prior written
      permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

******************************************************************
*/
package org.custommonkey.xmlunit;

import org.w3c.dom.Node;

/**
 * Parameter class for holding information about a <code>Node</code> within
 * a Difference instance  
 * @see Difference#getControlNodeDetail
 * @see Difference#getTestNodeDetail
 */
public class NodeDetail {
    private final String value;
    private final Node node; 
    private final String xpathLocation;
        
    /**
     * Constructor for NodeDetail.
     */
    public NodeDetail(String value, Node node, String xpathLocation) {
        this.value = value;
        this.node = node;
        this.xpathLocation = xpathLocation;
    }
        
        
    /**
     * Returns the node.
     * @return Node
     */
    public Node getNode() {
        return node;
    }

    /**
     * Returns the value.
     * @return String
     */
    public String getValue() {
        return value;
    }

    /**
     * Returns the xpathLocation.
     * @return String
     */
    public String getXpathLocation() {
        return xpathLocation;
    }

}

==> xmlunit-legacy-2.10.2-sources.jar: org/custommonkey/xmlunit/NodeDetail.java <==
/*
******************************************************************
Copyright (c) 2001,2015,2022 Jeff Martin, Tim Bacon
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
      copyright notice, this list of conditions and the following
      disclaimer in the documentation and/or other materials provided
      with the distribution.
    * Neither the name of the XMLUnit nor the names
      of its contributors may be used to endorse or promote products
      derived from this software without specific prior written
      permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

******************************************************************
*/
package org.custommonkey.xmlunit;

import org.w3c.dom.Node;

/**
 * Parameter class for holding information about a <code>Node</code> within
 * a Difference instance
 * @see Difference#getControlNodeDetail
 * @see Difference#getTestNodeDetail
 */
public class NodeDetail {
    private final String value;
    private final Node node;
    private final String xpathLocation;

    /**
     * Constructor for NodeDetail.
     * @param value value used for comparison
     * @param node the node itself
     * @param xpathLocation XPath leading to the node
     */
    public NodeDetail(String value, Node node, String xpathLocation) {
        this.value = value;
        this.node = node;
        this.xpathLocation = xpathLocation;
    }


    /**
     * Returns the node.
     * @return Node
     */
    public Node getNode() {
        return node;
    }

    /**
     * Returns the value.
     * @return the value
     */
    public String getValue() {
        return value;
    }

    /**
     * Returns the xpathLocation.
     * @return the XPath location
     */
    public String getXpathLocation() {
        return xpathLocation;
    }

}
